@@ -41,9 +41,8 @@ class IteratedLocalSearch(Algorithm):
         # enable resuming for ILS
         self.resume()
 
-        # initialize solution if no backup
-        if self.bestSolution is None:
-            self.initRun()
+        # initialize current solution
+        self.initRun()
 
         # passing global evaluation param from ILS
         ls = LocalSearch(self.initializer,
